@@ -184,15 +184,17 @@ int SuiteSparse_divcomplex
  *
  * SuiteSparse contains the following packages:
  *
- *  SuiteSparse_config version 4.5.6 (version always the same as SuiteSparse)
+ *  SuiteSparse_config version 5.1.0 (version always the same as SuiteSparse)
+ *  GraphBLAS       version 1.1.0
+ *  ssget           version 2.0.0
  *  AMD             version 2.4.6
  *  BTF             version 1.2.6
  *  CAMD            version 2.4.6
  *  CCOLAMD         version 2.9.6
  *  CHOLMOD         version 3.0.11
  *  COLAMD          version 2.9.6
- *  CSparse         version 3.1.9
- *  CXSparse        version 3.1.9
+ *  CSparse         version 3.2.0
+ *  CXSparse        version 3.2.0
  *  GPUQREngine     version 1.0.5
  *  KLU             version 1.3.8
  *  LDL             version 2.2.6
@@ -233,11 +235,11 @@ int SuiteSparse_version     /* returns SUITESPARSE_VERSION */
 */
 #define SUITESPARSE_HAS_VERSION_FUNCTION
 
-#define SUITESPARSE_DATE "Oct 3, 2017"
+#define SUITESPARSE_DATE "Dec 1, 2017"
 #define SUITESPARSE_VER_CODE(main,sub) ((main) * 1000 + (sub))
-#define SUITESPARSE_MAIN_VERSION 4
-#define SUITESPARSE_SUB_VERSION 5
-#define SUITESPARSE_SUBSUB_VERSION 6
+#define SUITESPARSE_MAIN_VERSION 5
+#define SUITESPARSE_SUB_VERSION 1
+#define SUITESPARSE_SUBSUB_VERSION 0
 #define SUITESPARSE_VERSION \
     SUITESPARSE_VER_CODE(SUITESPARSE_MAIN_VERSION,SUITESPARSE_SUB_VERSION)
 
